%bcond_with lwt
%bcond_with doc

Summary:        Composable build system for OCaml and Reason
Name:           ocaml-dune
Version:        3.16.0
Release:        3%{?dist}
License:        MIT AND ISC AND LGPL-2.0-only AND LGPL-2.0-only WITH OCaml-LGPL-linking-exception
URL:            https://dune.build
Source0:        https://github.com/ocaml/dune/archive/%{version}/dune-%{version}.tar.gz
Patch3000:      %{name}-no-lwt.patch

BuildRequires:  emacs make ocaml >= 4.08 ocaml-csexp-devel >= 1.5.0 ocaml-compiler-libs
%if %{with doc}
BuildRequires:  %{py3_dist sphinx}
BuildRequires:  %{py3_dist sphinx-copybutton}
BuildRequires:  %{py3_dist sphinx-rtd-theme}
%endif

%if %{with lwt}
BuildRequires:  ocaml-lwt-devel
%endif

Provides:       bundled(ocaml-build-path-prefix-map) = 0.3
Provides:       bundled(ocaml-cmdliner) = 1.1.1
Provides:       bundled(ocaml-incremental-cycles) = 1e2030a5d5183d84561cde142eecca40e03db2a3
Provides:       bundled(ocaml-inotify) = 2.3
Provides:       bundled(ocaml-opam-file-format) = 2.0.0
Provides:       bundled(ocaml-re) = 1.9.0
Provides:       bundled(ocaml-spawn) = 0.15.1
Provides:       dune = %{version}-%{release}
Provides:       ocaml-fiber = %{version}-%{release}
Provides:       ocaml-fiber-devel = %{version}-%{release}

Requires:       python3

%description
Dune is a build system designed for OCaml/Reason projects only. It focuses
on providing the user with a consistent experience and takes care of most of
the low-level details of OCaml compilation. All you have to do is provide a
description of your project and Dune will do the rest.

The scheme it implements is inspired from the one used inside Jane Street and
adapted to the open source world. It has matured over a long time and is used
daily by hundred of developers, which means that it is highly tested and
productive.

%if %{with doc}
%package        doc
License:        MIT AND BSD-2-Clause
Summary:        HTML documentation for %{name}
BuildArch:      noarch
 
Provides:       bundled(js-jquery) = 3.6.0
Provides:       bundled(js-underscore) = 1.13.1
 
%description    doc
HTML documentation for dune, a composable build system for OCaml.
%endif
 
%package        emacs
Summary:        Emacs support for %{name}
License:        ISC
Requires:       %{name} = %{version}-%{release}
Requires:       emacs-filesystem >= %{?_emacs_version}%{!?_emacs_version:0}
 
BuildArch:      noarch
 
%description    emacs
The %{name}-devel package contains Emacs integration with the dune build
system, a mode to edit dune files, and flymake support for dune files.
 
 
%package        action-plugin
Summary:        API for writing dynamic dune actions
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-glob = %{version}-%{release}
 
%description    action-plugin
This experimental library provides an API for writing dynamic Dune
actions.  Dynamic dune actions do not need to declare their dependencies
upfront; they are instead discovered automatically during the execution
of the action.
 
%package        action-plugin-devel
Summary:        Development files for %{name}-action-plugin
License:        MIT
Requires:       %{name}-action-plugin = %{version}-%{release}
Requires:       %{name}-glob-devel = %{version}-%{release}
 
%description    action-plugin-devel
The ocaml-dune-action-plugin-devel package contains libraries and
signature files for developing applications that use
ocaml-dune-action-plugin.
 
%package        build-info
Summary:        Embed build information in an executable
License:        MIT
Requires:       %{name} = %{version}-%{release}
 
%description    build-info
The build-info library allows access to information about how an
executable was built, such as the version of the project at which it was
built or the list of statically linked libraries with their versions.
It supports reporting the version from a version control system during
development to get a precise reference of when the executable was built.
 
%package        build-info-devel
Summary:        Development files for %{name}-build-info
License:        MIT
Requires:       %{name}-build-info = %{version}-%{release}
 
%description    build-info-devel
The ocaml-dune-build-info-devel package contains libraries and signature
files for developing applications that use ocaml-dune-build-info.
 
%package        configurator
Summary:        Helper library for gathering system configuration
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-stdune = %{version}-%{release}
 
%description    configurator
Dune-configurator is a small library that helps write OCaml scripts that
test features available on the system, in order to generate config.h
files for instance.  Among other things, dune-configurator allows one
to:
 
- test if a C program compiles
- query pkg-config
- import a #define from OCaml header files
- generate a config.h file
 
%package        configurator-devel
Summary:        Development files for %{name}-configurator
License:        MIT
Requires:       %{name}-configurator = %{version}-%{release}
Requires:       ocaml-stdune-devel = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
 
%description    configurator-devel
The ocaml-dune-configurator-devel package contains libraries and
signature files for developing applications that use
ocaml-dune-configurator.
 
%package        glob
Summary:        Parser and interpreter for dune language globs
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-private-libs = %{version}-%{release}
Requires:       ocaml-stdune = %{version}-%{release}
 
%description    glob
Dune-glob provides a parser and interpreter for globs as understood by
the dune language.
 
%package        glob-devel
Summary:        Development files for %{name}-glob
License:        MIT
Requires:       %{name}-glob = %{version}-%{release}
Requires:       %{name}-private-libs-devel = %{version}-%{release}
Requires:       ocaml-stdune-devel = %{version}-%{release}
 
%description    glob-devel
The ocaml-dune-glob-devel package contains libraries and signature files
for developing applications that use ocaml-dune-glob.
 
%package        private-libs
Summary:        Private dune libraries
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-stdune = %{version}-%{release}
 
%description    private-libs
This package contains code that is shared between various dune-xxx
packages.  However, it is not meant for public consumption and provides
no stability guarantee.
 
%package        private-libs-devel
Summary:        Development files for %{name}-private-libs
License:        MIT
Requires:       %{name}-private-libs = %{version}-%{release}
Requires:       ocaml-dyn-devel = %{version}-%{release}
 
%description    private-libs-devel
The ocaml-dune-private-libs-devel package contains libraries and
signature files for other dune packages.  Do not use.
 
%package        rpc
Summary:        Communicate with dune using rpc
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-stdune = %{version}-%{release}
Requires:       ocaml-xdg = %{version}-%{release}
 
%description    rpc
This package contains a library used to communicate with dune over rpc.
 
%package        rpc-devel
Summary:        Development files for %{name}-rpc
License:        MIT
Requires:       %{name}-rpc = %{version}-%{release}
Requires:       ocaml-stdune-devel = %{version}-%{release}
Requires:       ocaml-xdg-devel = %{version}-%{release}
 
%description    rpc-devel
The ocaml-dune-rpc-devel package contains libraries and signature files
for developing applications that use ocaml-rpc.
 
%if %{with lwt}
%package        rpc-lwt
Summary:        Communicate with dune using rpc and Lwt
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-rpc = %{version}-%{release}
 
%description    rpc-lwt
This package contains a library used to communicate with dune over rpc
using Lwt.
 
%package        rpc-lwt-devel
Summary:        Development files for %{name}-rpc-lwt
License:        MIT
Requires:       %{name}-rpc-lwt = %{version}-%{release}
Requires:       %{name}-rpc-devel = %{version}-%{release}
Requires:       ocaml-csexp-devel
Requires:       ocaml-lwt-devel
Requires:       ocaml-result-devel
 
%description    rpc-lwt-devel
The ocaml-dune-rpc-lwt-devel package contains libraries and signature
files for developing applications that use ocaml-rpc-lwt.
%endif
 
%package        site
Summary:        Embed location information inside executables and libraries
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-private-libs = %{version}-%{release}
 
%description    site
This library enables embedding location information inside executables
and libraries.
 
%package        site-devel
Summary:        Development files for %{name}-site
License:        MIT
Requires:       %{name}-site = %{version}-%{release}
Requires:       %{name}-private-libs-devel = %{version}-%{release}
 
%description    site-devel
The ocaml-dune-site-devel package contains libraries and signature files
for developing applications that use ocaml-dune-site.
 
%package     -n ocaml-chrome-trace
Summary:        Chrome trace event generation library
License:        MIT
Requires:       %{name} = %{version}-%{release}
 
%description -n ocaml-chrome-trace
Library to output trace data to a file in Chrome's trace_event format.
This format is compatible with chrome trace viewer (chrome://tracing).
The trace viewer is part of the catapult project.
 
%package     -n ocaml-chrome-trace-devel
Summary:        Development files for ocaml-chrome-trace
License:        MIT
Requires:       ocaml-chrome-trace = %{version}-%{release}
 
%description -n ocaml-chrome-trace-devel
The ocaml-dyn-devel package contains libraries and signature files for
developing applications that use ocaml-dyn.
 
%package     -n ocaml-dyn
Summary:        Dynamic types
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-ordering = %{version}-%{release}
 
%description -n ocaml-dyn
This library supports dynamic types in OCaml.
 
%package     -n ocaml-dyn-devel
Summary:        Development files for ocaml-dyn
License:        MIT
Requires:       ocaml-dyn = %{version}-%{release}
Requires:       ocaml-ordering-devel = %{version}-%{release}
 
%description -n ocaml-dyn-devel
The ocaml-dyn-devel package contains libraries and signature files for
developing applications that use ocaml-dyn.
 
%package     -n ocaml-ocamlc-loc
Summary:        Parse OCaml compiler output into structured form
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-dyn = %{version}-%{release}
 
%description -n ocaml-ocamlc-loc
Parse OCaml compiler output into structured form.
 
%package     -n ocaml-ocamlc-loc-devel
Summary:        Development files for ocaml-ocamlc-loc
License:        MIT
Requires:       ocaml-ocamlc-loc = %{version}-%{release}
Requires:       ocaml-dyn-devel = %{version}-%{release}
 
%description -n ocaml-ocamlc-loc-devel
The ocaml-ordering-devel package contains libraries and signature files
for developing applications that use ocaml-ocamlc-loc.
 
%package     -n ocaml-ordering
Summary:        Element ordering
License:        MIT
Requires:       %{name} = %{version}-%{release}
 
%description -n ocaml-ordering
Element ordering in OCaml.
 
%package     -n ocaml-ordering-devel
Summary:        Development files for ocaml-ordering
License:        MIT
Requires:       ocaml-ordering = %{version}-%{release}
 
%description -n ocaml-ordering-devel
The ocaml-ordering-devel package contains libraries and signature files
for developing applications that use ocaml-ordering.
 
%package     -n ocaml-stdune
Summary:        Dune's unstable standard library
License:        MIT
Requires:       %{name} = %{version}-%{release}
Requires:       ocaml-dyn = %{version}-%{release}
 
%description -n ocaml-stdune
This package contains Dune's unstable standard library.
 
%package     -n ocaml-stdune-devel
Summary:        Development files for ocaml-stdune
License:        MIT
Requires:       ocaml-stdune = %{version}-%{release}
Requires:       ocaml-dyn-devel = %{version}-%{release}
Requires:       ocaml-csexp-devel
 
%description -n ocaml-stdune-devel
The ocaml-stdune-devel package contains libraries and signature files
for developing applications that use ocaml-stdune.
 
%package     -n ocaml-xdg
Summary:        XDG Base Directory Specification
License:        MIT
Requires:       %{name} = %{version}-%{release}
 
%description -n ocaml-xdg
This package contains the XDG Base Directory Specification.
 
%package     -n ocaml-xdg-devel
Summary:        Development files for ocaml-xdg
License:        MIT
Requires:       ocaml-xdg = %{version}-%{release}
 
%description -n ocaml-xdg-devel
The ocaml-xdg-devel package contains libraries and signature files for
developing applications that use ocaml-xdg.

%prep
%setup -n dune-%{version}
%if %{without lwt}
%patch 3000 -p1
rm -fr otherlibs/dune-rpc-lwt dune-rpc-lwt.opam
%endif

%build
./configure \
  --bindir %{_bindir} \
  --datadir %{_datadir} \
  --docdir %{_prefix}/doc \
  --etcdir %{_sysconfdir} \
  --libdir %{_libdir}/ocaml \
  --libexecdir %{_libdir}/ocaml \
  --mandir %{_mandir} \
  --sbindir %{_sbindir}

%make_build release
%if %{with doc}
%make_build doc
%endif

./dune.exe build %{?_smp_mflags} --verbose --release @install

%install
%make_install

./dune.exe install --destdir=%{buildroot}

rm -fr %{buildroot}%{_prefix}/doc

cd %{buildroot}%{_emacs_sitelispdir}
%_emacs_bytecompile *.el
cd -


%files
%license LICENSE.md
%doc README.md CHANGES.md
%{_bindir}/dune
%{_libdir}/ocaml/stublibs/
%{_mandir}/man*/dune*

%if %{with doc}
%files doc
%doc doc/_build/*
%endif

%files emacs
%{_emacs_sitelispdir}/dune*

%files action-plugin
%{_libdir}/ocaml/dune-action-plugin/META
%{_libdir}/ocaml/dune-action-plugin/*.{cma,cmi,cmxs}

%files action-plugin-devel
%{_libdir}/ocaml/dune-action-plugin/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-action-plugin/dune-package
%{_libdir}/ocaml/dune-action-plugin/opam

%files build-info
%{_libdir}/ocaml/dune-build-info/META
%{_libdir}/ocaml/dune-build-info/*.{cma,cmi,cmxs}

%files build-info-devel
%{_libdir}/ocaml/dune-build-info/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-build-info/dune-package
%{_libdir}/ocaml/dune-build-info/opam

%files configurator
%{_libdir}/ocaml/dune/META
%{_libdir}/ocaml/dune-configurator/META
%{_libdir}/ocaml/dune-configurator/*.{cma,cmi,cmxs}
%{_libdir}/ocaml/dune-configurator/.private/*.{cma,cmi,cmxs}

%files configurator-devel
%{_libdir}/ocaml/dune-configurator/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-configurator/.private/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-configurator/dune-package
%{_libdir}/ocaml/dune/dune-package
%{_libdir}/ocaml/dune/opam
%{_libdir}/ocaml/dune-configurator/opam

%files glob
%{_libdir}/ocaml/dune-glob/META
%{_libdir}/ocaml/dune-glob/*.{cma,cmi,cmxs}

%files glob-devel
%{_libdir}/ocaml/dune-glob/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-glob/dune-package
%{_libdir}/ocaml/dune-glob/opam

%files private-libs
%{_libdir}/ocaml/dune-private-libs/META
%{_libdir}/ocaml/dune-private-libs/*/*.{cma,cmi,cmxs}

%files private-libs-devel
%{_libdir}/ocaml/dune-private-libs/*/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-private-libs/dune-package
%{_libdir}/ocaml/dune-private-libs/opam

%files rpc
%{_libdir}/ocaml/dune-rpc/META
%{_libdir}/ocaml/dune-rpc/*/*.{cma,cmi,cmxs}
%{_libdir}/ocaml/dune-rpc/*.{cma,cmi,cmxs}

%files rpc-devel
%{_libdir}/ocaml/dune-rpc/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-rpc/*/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-rpc/dune-package
%{_libdir}/ocaml/dune-rpc/opam

%if %{with lwt}
%files rpc-lwt
%{_libdir}/ocaml/dune-rpc-lwt/META
%{_libdir}/ocaml/dune-rpc-lwt/*.{cma,cmi,cmxs}

%files rpc-lwt-devel
%{_libdir}/ocaml/dune-rpc-lwt/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-rpc-lwt/dune-package
%{_libdir}/ocaml/dune-rpc-lwt/opam
%endif

%files site
%{_libdir}/ocaml/dune-site/META
%{_libdir}/ocaml/dune-site/*/*.{cma,cmi,cmxs,cmo}
%{_libdir}/ocaml/dune-site/*.{cma,cmi,cmxs}

%files site-devel
%{_libdir}/ocaml/dune-site/*/*.{a,cmt,cmti,cmx,cmxa,ml,mli,o}
%{_libdir}/ocaml/dune-site/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dune-site/dune-package
%{_libdir}/ocaml/dune-site/opam

%files -n ocaml-chrome-trace
%{_libdir}/ocaml/chrome-trace/META
%{_libdir}/ocaml/chrome-trace/*.{cma,cmi,cmxs}

%files -n ocaml-chrome-trace-devel
%{_libdir}/ocaml/chrome-trace/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/chrome-trace/dune-package
%{_libdir}/ocaml/chrome-trace/opam

%files -n ocaml-dyn
%{_libdir}/ocaml/dyn/META
%{_libdir}/ocaml/dyn/*.{cma,cmi,cmxs}
%{_libdir}/ocaml/dyn/*/*.{cma,cmi,cmxs}

%files -n ocaml-dyn-devel
%{_libdir}/ocaml/dyn/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dyn/*/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/dyn/dune-package
%{_libdir}/ocaml/dyn/opam

%files -n ocaml-ocamlc-loc
%{_libdir}/ocaml/ocamlc-loc/META
%{_libdir}/ocaml/ocamlc-loc/*.{cma,cmi,cmxs}

%files -n ocaml-ocamlc-loc-devel
%{_libdir}/ocaml/ocamlc-loc/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/ocamlc-loc/dune-package
%{_libdir}/ocaml/ocamlc-loc/opam

%files -n ocaml-ordering
%{_libdir}/ocaml/ordering/META
%{_libdir}/ocaml/ordering/*.{cma,cmi,cmxs}

%files -n ocaml-ordering-devel
%{_libdir}/ocaml/ordering/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/ordering/dune-package
%{_libdir}/ocaml/ordering/opam

%files -n ocaml-stdune
%{_libdir}/ocaml/stdune/META
%{_libdir}/ocaml/stdune/*.{cma,cmi,cmxs}
%{_libdir}/ocaml/stdune/*/*.{cma,cmi,cmxs}

%files -n ocaml-stdune-devel
%{_libdir}/ocaml/stdune/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/stdune/*/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/stdune/dune-package
%{_libdir}/ocaml/stdune/opam

%files -n ocaml-xdg
%{_libdir}/ocaml/xdg/META
%{_libdir}/ocaml/xdg/*.{cma,cmi,cmxs}

%files -n ocaml-xdg-devel
%{_libdir}/ocaml/xdg/*.{a,cmt,cmti,cmx,cmxa,ml,mli}
%{_libdir}/ocaml/xdg/dune-package
%{_libdir}/ocaml/xdg/opam

%changelog
* Thu Aug 29 2024 cunshunxia <cunshunxia@tencent.com> - 3.16.0-3
- move sphinx build requirements into doc bcond.

* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.16.0-2
- Rebuilt for loongarch release

* Fri Jun 21 2024 cunshunxia <cunshunxia@tencent.com> - 3.16.0-1
- upgrade to 3.16.0 for ocaml 5.2.0.

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.10.0-2
- Rebuilt for OpenCloudOS Stream 23.09

* Tue Aug 08 2023 cunshunxia <cunshunxia@tencent.com> - 3.10.0-1
- upgrade to 3.10.0

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 3.7.0-2
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 cunshunxia <cunshunxia@tencent.com> - 3.7.0-1
- initial build
